@@ -1,8 +1,7 @@
-#ifndef THUMBNAILER_H
-#define THUMBNAILER_H
-
+#pragma once
 #include <QString>
 #include <QQuickImageProvider>
+#include "filebrowsing_export.h"
 
 class AsyncImageResponse : public QQuickImageResponse
 {
@@ -18,10 +17,9 @@ private:
     QString m_error;
 };
 
-class Thumbnailer : public QQuickAsyncImageProvider
+class FILEBROWSING_EXPORT Thumbnailer : public QQuickAsyncImageProvider
 {
 public:
     QQuickImageResponse *requestImageResponse(const QString &id, const QSize &requestedSize) override;
 };
 
-#endif // THUMBNAILER_H
